==> igniteui-react-layouts-16.16.0.tgz: package/esm2015/lib/igr-property-editor-property-description.js <==
import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { PropertyEditorValueType_$type } from "./PropertyEditorValueType";
import { IgrPropertyEditorDescriptionObject } from "./igr-property-editor-description-object";
import { IgrPropertyEditorDescriptionObjectCollection } from "./igr-property-editor-description-object-collection";
import { IgrPropertyEditorPropertyDescriptionButtonClickEventArgs } from "./igr-property-editor-property-description-button-click-event-args";
import { IgrPropertyEditorPropertyDescriptionChangedEventArgs } from "./igr-property-editor-property-description-changed-event-args";
import { IgrPropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgs } from "./igr-property-editor-property-description-target-property-updating-event-args";
import { PropertyEditorPropertyDescription } from "./PropertyEditorPropertyDescription";
import { TypeRegistrar } from "igniteui-react-core";
import { NamePatcher, getModifiedProps, isValidProp, ensureEnum, ensureBool, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
import { PropertyEditorDescriptionObjectCollection as PropertyEditorDescriptionObjectCollection_internal } from "./PropertyEditorDescriptionObjectCollection";
import { PropertyEditorDescriptionObject } from "./PropertyEditorDescriptionObject";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
export class IgrPropertyEditorPropertyDescription extends React.Component {
    constructor(props) {
        super(props);
        this._complexValues = null;
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._buttonClicked = null;
        this._buttonClicked_wrapped = null;
        this._changed = null;
        this._changed_wrapped = null;
        this._targetPropertyUpdating = null;
        this._targetPropertyUpdating_wrapped = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new PropertyEditorPropertyDescription();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    onImplementationCreated() {
    }
    componentDidMount() {
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    render() {
        return null;
    }
    get propertyPath() {
        return this.i.al;
    }
    set propertyPath(v) {
        this.i.al = v;
    }
    get label() {
        return this.i.aj;
    }
    set label(v) {
        this.i.aj = v;
    }
    get valueType() {
        return this.i.n;
    }
    set valueType(v) {
        this.i.n = ensureEnum(PropertyEditorValueType_$type, v);
    }
    get propertyDescriptionType() {
        return this.i.ak;
    }
    set propertyDescriptionType(v) {
        this.i.ak = v;
    }
    get shouldOverrideDefaultEditor() {
        return this.i.q;
    }
    set shouldOverrideDefaultEditor(v) {
        this.i.q = ensureBool(v);
    }
    get elementDescriptionType() {
        return this.i.ai;
    }
    set elementDescriptionType(v) {
        this.i.ai = v;
    }
    get dropDownNames() {
        return this.i.c;
    }
    set dropDownNames(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.c = v;
    }
    get dropDownValues() {
        return this.i.d;
    }
    set dropDownValues(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.d = v;
    }
    get primitiveValue() {
        return this.i.ad;
    }
    set primitiveValue(v) {
        this.i.ad = v;
    }
    get min() {
        return this.i.z;
    }
    set min(v) {
        this.i.z = +v;
    }
    get editorWidth() {
        return this.i.w;
    }
    set editorWidth(v) {
        this.i.w = +v;
    }
    get labelWidth() {
        return this.i.x;
    }
    set labelWidth(v) {
        this.i.x = +v;
    }
    get max() {
        return this.i.y;
    }
    set max(v) {
        this.i.y = +v;
    }
    get step() {
        return this.i.aa;
    }
    set step(v) {
        this.i.aa = +v;
    }
    get complexValue() {
        if (this.i.g == null) {
            return null;
        }
        if (!this.i.g.externalObject) {
            let e = new IgrPropertyEditorDescriptionObject();
            e._implementation = this.i.g;
            this.i.g.externalObject = e;
        }
        return this.i.g.externalObject;
    }
    set complexValue(v) {
        v == null ? this.i.g = null : this.i.g = v.i;
    }
    get complexValues() {
        if (this._complexValues === null) {
            let coll = new IgrPropertyEditorDescriptionObjectCollection();
            let innerColl = this.i.i;
            if (!innerColl) {
                innerColl = new PropertyEditorDescriptionObjectCollection_internal();
            }
            this._complexValues = coll._fromInner(innerColl);
            this.i.i = innerColl;
        }
        return this._complexValues;
    }
    set complexValues(v) {
        if (this._complexValues !== null) {
            this._complexValues._setSyncTarget(null);
            this._complexValues = null;
        }
        let coll = new IgrPropertyEditorDescriptionObjectCollection();
        this._complexValues = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(PropertyEditorDescriptionObject.$type);
        let innerColl = this.i.i;
        if (!innerColl) {
            innerColl = new PropertyEditorDescriptionObjectCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._complexValues._setSyncTarget(syncColl);
        this.i.i = innerColl;
    }
    findByName(name) {
        if (this.complexValue && this.complexValue.name && this.complexValue.name == name) {
            return this.complexValue;
        }
        if (this.complexValues != null && this.complexValues.findByName && this.complexValues.findByName(name)) {
            return this.complexValues.findByName(name);
        }
        return null;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("PropertyEditorPropertyDescription");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    get buttonClicked() {
        return this._buttonClicked;
    }
    set buttonClicked(ev) {
        if (this._buttonClicked_wrapped !== null) {
            this.i.buttonClicked = delegateRemove(this.i.buttonClicked, this._buttonClicked_wrapped);
            this._buttonClicked_wrapped = null;
            this._buttonClicked = null;
        }
        this._buttonClicked = ev;
        this._buttonClicked_wrapped = (o, e) => {
            let outerArgs = new IgrPropertyEditorPropertyDescriptionButtonClickEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeButtonClicked) {
                this.beforeButtonClicked(this, outerArgs);
            }
            if (this._buttonClicked) {
                this._buttonClicked(this, outerArgs);
            }
        };
        this.i.buttonClicked = delegateCombine(this.i.buttonClicked, this._buttonClicked_wrapped);
        ;
    }
    get changed() {
        return this._changed;
    }
    set changed(ev) {
        if (this._changed_wrapped !== null) {
            this.i.changed = delegateRemove(this.i.changed, this._changed_wrapped);
            this._changed_wrapped = null;
            this._changed = null;
        }
        this._changed = ev;
        this._changed_wrapped = (o, e) => {
            let outerArgs = new IgrPropertyEditorPropertyDescriptionChangedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeChanged) {
                this.beforeChanged(this, outerArgs);
            }
            if (this._changed) {
                this._changed(this, outerArgs);
            }
        };
        this.i.changed = delegateCombine(this.i.changed, this._changed_wrapped);
        ;
    }
    get targetPropertyUpdating() {
        return this._targetPropertyUpdating;
    }
    set targetPropertyUpdating(ev) {
        if (this._targetPropertyUpdating_wrapped !== null) {
            this.i.targetPropertyUpdating = delegateRemove(this.i.targetPropertyUpdating, this._targetPropertyUpdating_wrapped);
            this._targetPropertyUpdating_wrapped = null;
            this._targetPropertyUpdating = null;
        }
        this._targetPropertyUpdating = ev;
        this._targetPropertyUpdating_wrapped = (o, e) => {
            let outerArgs = new IgrPropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeTargetPropertyUpdating) {
                this.beforeTargetPropertyUpdating(this, outerArgs);
            }
            if (this._targetPropertyUpdating) {
                this._targetPropertyUpdating(this, outerArgs);
            }
        };
        this.i.targetPropertyUpdating = delegateCombine(this.i.targetPropertyUpdating, this._targetPropertyUpdating_wrapped);
        ;
    }
}

==> igniteui-react-layouts-18.1.0.tgz: package/esm2015/lib/igr-property-editor-property-description.js <==
import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { PropertyEditorValueType_$type } from "./PropertyEditorValueType";
import { IgrPropertyEditorDescriptionObject } from "./igr-property-editor-description-object";
import { IgrPropertyEditorDescriptionObjectCollection } from "./igr-property-editor-description-object-collection";
import { IgrPropertyEditorPropertyDescriptionButtonClickEventArgs } from "./igr-property-editor-property-description-button-click-event-args";
import { IgrPropertyEditorPropertyDescriptionChangedEventArgs } from "./igr-property-editor-property-description-changed-event-args";
import { IgrPropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgs } from "./igr-property-editor-property-description-target-property-updating-event-args";
import { PropertyEditorPropertyDescription } from "./PropertyEditorPropertyDescription";
import { TypeRegistrar } from "igniteui-react-core";
import { NamePatcher, getModifiedProps, isValidProp, ensureEnum, ensureBool, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
import { PropertyEditorDescriptionObjectCollection as PropertyEditorDescriptionObjectCollection_internal } from "./PropertyEditorDescriptionObjectCollection";
import { PropertyEditorDescriptionObject } from "./PropertyEditorDescriptionObject";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
export class IgrPropertyEditorPropertyDescription extends React.Component {
    constructor(props) {
        super(props);
        this._complexValues = null;
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._buttonClicked = null;
        this._buttonClicked_wrapped = null;
        this._changed = null;
        this._changed_wrapped = null;
        this._targetPropertyUpdating = null;
        this._targetPropertyUpdating_wrapped = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new PropertyEditorPropertyDescription();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    onImplementationCreated() {
    }
    componentDidMount() {
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    render() {
        return null;
    }
    get propertyPath() {
        return this.i.al;
    }
    set propertyPath(v) {
        this.i.al = v;
    }
    get label() {
        return this.i.aj;
    }
    set label(v) {
        this.i.aj = v;
    }
    get valueType() {
        return this.i.n;
    }
    set valueType(v) {
        this.i.n = ensureEnum(PropertyEditorValueType_$type, v);
    }
    get propertyDescriptionType() {
        return this.i.ak;
    }
    set propertyDescriptionType(v) {
        this.i.ak = v;
    }
    get shouldOverrideDefaultEditor() {
        return this.i.q;
    }
    set shouldOverrideDefaultEditor(v) {
        this.i.q = ensureBool(v);
    }
    get elementDescriptionType() {
        return this.i.ai;
    }
    set elementDescriptionType(v) {
        this.i.ai = v;
    }
    get dropDownNames() {
        return this.i.c;
    }
    set dropDownNames(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.c = v;
    }
    get dropDownValues() {
        return this.i.d;
    }
    set dropDownValues(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.d = v;
    }
    get primitiveValue() {
        return this.i.ad;
    }
    set primitiveValue(v) {
        this.i.ad = v;
    }
    get min() {
        return this.i.z;
    }
    set min(v) {
        this.i.z = +v;
    }
    get editorWidth() {
        return this.i.w;
    }
    set editorWidth(v) {
        this.i.w = +v;
    }
    get labelWidth() {
        return this.i.x;
    }
    set labelWidth(v) {
        this.i.x = +v;
    }
    get max() {
        return this.i.y;
    }
    set max(v) {
        this.i.y = +v;
    }
    get step() {
        return this.i.aa;
    }
    set step(v) {
        this.i.aa = +v;
    }
    get complexValue() {
        const r = this.i.g;
        if (r == null) {
            return null;
        }
        if (!r.externalObject) {
            let e = new IgrPropertyEditorDescriptionObject();
            if (e.i.setNativeElement) {
                e.i.setNativeElement(r);
            }
            else {
                e._implementation = r;
            }
            r.externalObject = e;
        }
        return r.externalObject;
    }
    set complexValue(v) {
        v == null ? this.i.g = null : this.i.g = v.i;
    }
    get complexValues() {
        if (this._complexValues === null) {
            let coll = new IgrPropertyEditorDescriptionObjectCollection();
            let innerColl = this.i.i;
            if (!innerColl) {
                innerColl = new PropertyEditorDescriptionObjectCollection_internal();
            }
            this._complexValues = coll._fromInner(innerColl);
            this.i.i = innerColl;
        }
        return this._complexValues;
    }
    set complexValues(v) {
        if (this._complexValues !== null) {
            this._complexValues._setSyncTarget(null);
            this._complexValues = null;
        }
        let coll = new IgrPropertyEditorDescriptionObjectCollection();
        this._complexValues = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(PropertyEditorDescriptionObject.$type);
        let innerColl = this.i.i;
        if (!innerColl) {
            innerColl = new PropertyEditorDescriptionObjectCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._complexValues._setSyncTarget(syncColl);
        this.i.i = innerColl;
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        if (this.complexValue && this.complexValue.name && this.complexValue.name == name) {
            return this.complexValue;
        }
        if (this.complexValues != null && this.complexValues.findByName && this.complexValues.findByName(name)) {
            return this.complexValues.findByName(name);
        }
        return null;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("PropertyEditorPropertyDescription");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    get buttonClicked() {
        return this._buttonClicked;
    }
    set buttonClicked(ev) {
        if (this._buttonClicked_wrapped !== null) {
            this.i.buttonClicked = delegateRemove(this.i.buttonClicked, this._buttonClicked_wrapped);
            this._buttonClicked_wrapped = null;
            this._buttonClicked = null;
        }
        this._buttonClicked = ev;
        this._buttonClicked_wrapped = (o, e) => {
            let outerArgs = new IgrPropertyEditorPropertyDescriptionButtonClickEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeButtonClicked) {
                this.beforeButtonClicked(this, outerArgs);
            }
            if (this._buttonClicked) {
                this._buttonClicked(this, outerArgs);
            }
        };
        this.i.buttonClicked = delegateCombine(this.i.buttonClicked, this._buttonClicked_wrapped);
        ;
    }
    get changed() {
        return this._changed;
    }
    set changed(ev) {
        if (this._changed_wrapped !== null) {
            this.i.changed = delegateRemove(this.i.changed, this._changed_wrapped);
            this._changed_wrapped = null;
            this._changed = null;
        }
        this._changed = ev;
        this._changed_wrapped = (o, e) => {
            let outerArgs = new IgrPropertyEditorPropertyDescriptionChangedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeChanged) {
                this.beforeChanged(this, outerArgs);
            }
            if (this._changed) {
                this._changed(this, outerArgs);
            }
        };
        this.i.changed = delegateCombine(this.i.changed, this._changed_wrapped);
        ;
    }
    get targetPropertyUpdating() {
        return this._targetPropertyUpdating;
    }
    set targetPropertyUpdating(ev) {
        if (this._targetPropertyUpdating_wrapped !== null) {
            this.i.targetPropertyUpdating = delegateRemove(this.i.targetPropertyUpdating, this._targetPropertyUpdating_wrapped);
            this._targetPropertyUpdating_wrapped = null;
            this._targetPropertyUpdating = null;
        }
        this._targetPropertyUpdating = ev;
        this._targetPropertyUpdating_wrapped = (o, e) => {
            let outerArgs = new IgrPropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeTargetPropertyUpdating) {
                this.beforeTargetPropertyUpdating(this, outerArgs);
            }
            if (this._targetPropertyUpdating) {
                this._targetPropertyUpdating(this, outerArgs);
            }
        };
        this.i.targetPropertyUpdating = delegateCombine(this.i.targetPropertyUpdating, this._targetPropertyUpdating_wrapped);
        ;
    }
}
